"""Brand widget layer — chips, tiles, empty states, confirm, delegates, props."""

from __future__ import annotations

from mgf.brand_qt.widgets.chips import Badge, StatusChip
from mgf.brand_qt.widgets.confirm import confirm_action
from mgf.brand_qt.widgets.delegates import STATUS_ROLE, StatusChipDelegate
from mgf.brand_qt.widgets.empty import (
    EmptyState,
    EmptyStateBinding,
    bind_empty_state,
    lattice_tile,
)
from mgf.brand_qt.widgets.props import apply_label_class, set_mgf
from mgf.brand_qt.widgets.tiles import StatTile

__all__ = [
    "STATUS_ROLE",
    "Badge",
    "EmptyState",
    "EmptyStateBinding",
    "StatTile",
    "StatusChip",
    "StatusChipDelegate",
    "apply_label_class",
    "bind_empty_state",
    "confirm_action",
    "lattice_tile",
    "set_mgf",
]
